Mock Library for the Oxide Rust SDK
Generated wrapping mocking library based on
httpmock. It provides operation-specific
wrappers around predicates and responses. This can be used to test uses of the
Oxide Rust SDK.
Modules
- operations
WhenandThenwrappers for each operation. Each can be converted to its inner type with a call tointo_inner(). This can be used to explicitly deviate from permitted values.
Traits
- Mock
Server Ext - An extension trait for
MockServerthat adds a method for each operation. These are the equivalent of type-checkedmock()calls.